"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.createConfig = void 0;
const resolve_1 = __importDefault(require("./plugins/resolve"));
const style_1 = __importDefault(require("./plugins/style"));
const svg_1 = __importDefault(require("./plugins/svg"));
const babel_1 = __importDefault(require("./plugins/babel"));
const terser_1 = __importDefault(require("./plugins/terser"));
const typescript_1 = __importDefault(require("./plugins/typescript"));
const server_1 = __importDefault(require("./plugins/server"));
//
const pluginProgress = require("rollup-plugin-progress");
const pluginFilesize = require("rollup-plugin-filesize");
const { compress, serve, bundle, verbose, } = process.env;
exports.createConfig = (options) => {
    const { input, name, dir, ecma = 6, plugins = {}, pkg = require(process.cwd() + "/package.json"), ...opt } = options;
    const { resolve, typescript, style, terser, server } = plugins;
    const esmodules = process.env.ecma ? process.env.ecma === '6' : ecma === 6;
    const format = esmodules ? "esm" : "iife";
    const doBundle = !!bundle || opt.bundle;
    const doCompress = !!compress || opt.compress;
    const external = doBundle ? [] : Object.keys(pkg.dependencies).concat(["tslib"]);
    const tsconfigDefaults = {
        typescript: require('typescript'),
        objectHashIgnoreUnknownHack: true,
        compilerOptions: {
            declaration: !doBundle,
            target: 'esm'
        }
    };
    const _config = {
        input,
        external,
        output: {
            format,
            name,
            file: dir ? undefined : `${name}.${esmodules ? 'mjs' : 'js'}`,
            dir: dir ? dir : bundle ? 'dist/' : undefined
        },
        plugins: [
            resolve_1.default(resolve),
            typescript_1.default({
                tsconfigDefaults,
                ...typescript,
                verbosity: !!verbose ? typescript && typescript.verbosity !== undefined ? typescript.verbosity : 2 : 0
            }),
            style_1.default({
                ...style,
                esmodules,
                compress: !doCompress && style && style.compress === true ? true : !doCompress
            }),
            svg_1.default(),
            pluginProgress(),
            // https://github.com/ritz078/rollup-plugin-filesize/issues/57
            // pluginFilesize(),
            doBundle && babel_1.default({ esmodules }),
            doCompress && terser_1.default(terser),
            !!serve && server_1.default(server),
        ].filter((p) => !!p)
    };
    return _config;
};
exports.default = exports.createConfig;
